# Cookbook

This cookbook contains quick references and more involved tutorials for a variety of `qp` use cases.

- **<project:./ensemblemanipulation.md>**
  - contains examples of Ensemble creation and basic usage.
- **<project:./datamanipulation.md>**
  - covers examples that access or modify the underlying Ensemble data in some way.
- **<project:./conversion.md>**
  - covers conversion examples between the different parameterization types.

```{toctree}
:titlesonly:
:hidden:

ensemblemanipulation
datamanipulation
conversion

```
